# Brand

> Assets for the Agent Client Protocol brand.

Following these guidelines helps maintain brand integrity while supporting ACP's mission to standardize communication between code editors and coding agents.

[Download all of the assets here](https://cdn.agentclientprotocol.com/acp-brand.zip)

## Logo

The ACP logo can be used with the "ACP" logomark with or without a gradient.
We provide a vertical and horizontal variant for display flexibility.

<Frame>
  <img src="https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo.webp?fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=7b195e919dc200238c6029eb190235c0" alt="Agentic Client Protocol Logo" data-og-width="3840" width="3840" data-og-height="2160" height="2160" data-path="assets/acp-docs-logo.webp" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo.webp?w=280&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=187219fd4aeeda3e61270114af4286ac 280w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo.webp?w=560&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=b5ceae25a689b096e7cca93c664b6ba8 560w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo.webp?w=840&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=508da70ccf53ce30bebd0ab69409b6f2 840w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo.webp?w=1100&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=c27bb2af8316c5abb588ad85e4c50248 1100w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo.webp?w=1650&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=26faa711779a68bfb24486bd071c825b 1650w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo.webp?w=2500&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=adc02618a11ae71fb7e75e8c7c8efab9 2500w" />
</Frame>

## Logomark

The logomark has a variation that includes a slight gradient on the bottom right part of it.
We don't enforce the use of one version over the other, meaning you can choose to use either of them as you wish, as long as you respect using it in pure white or pure black.

<Frame>
  <img src="https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo-mark.webp?fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=3ab81fb3792f3c613bcecafec5da05cf" alt="Agentic Client Protocol Logomark" data-og-width="3840" width="3840" data-og-height="2160" height="2160" data-path="assets/acp-docs-logo-mark.webp" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo-mark.webp?w=280&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=33123e71c5c96bcd99dcdfc985d682a1 280w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo-mark.webp?w=560&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=1b77814322c2607aaba4c0f051accd88 560w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo-mark.webp?w=840&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=b44744e4e0a4c41632445f19245db490 840w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo-mark.webp?w=1100&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=a4f1156b5781cd743dd66b4d8b890ecf 1100w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo-mark.webp?w=1650&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=6672b8bd73cab06c1426d8ee183de7ca 1650w, https://mintcdn.com/zed-685ed6d6/0gwpXYa47bQsPCSW/assets/acp-docs-logo-mark.webp?w=2500&fit=max&auto=format&n=0gwpXYa47bQsPCSW&q=85&s=d39cbbe01181dc721f7c849759862e0c 2500w" />
</Frame>


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://agentclientprotocol.com/llms.txt